@@ -13,9 +13,8 @@
 class BoolectorException : public std::exception
 {
  public:
-  BoolectorException (const char* msg) : msg (msg) {}
-    virtual ~BoolectorException() _GLIBCXX_USE_NOEXCEPT {}
-  const char* what () const _GLIBCXX_USE_NOEXCEPT  { return msg.c_str(); }
+  BoolectorException (const char* msg) : msg (msg) {}    virtual ~BoolectorException() _NOEXCEPT {}
+  const char* what () const _NOEXCEPT  { return msg.c_str(); }
 
  protected:
   std::string msg;
